# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class RetargetingListServiceRuleTargetList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_open': 'RetargetingListServiceIsOpen',
        'is_preset': 'RetargetingListServiceIsPreset',
        'reach_period': 'int',
        'retargeting_tag_id': 'str',
        'rules': 'list[RetargetingListServiceRule]'
    }

    attribute_map = {
        'is_open': 'isOpen',
        'is_preset': 'isPreset',
        'reach_period': 'reachPeriod',
        'retargeting_tag_id': 'retargetingTagId',
        'rules': 'rules'
    }

    def __init__(self, is_open=None, is_preset=None, reach_period=None, retargeting_tag_id=None, rules=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceRuleTargetList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_open = None
        self._is_preset = None
        self._reach_period = None
        self._retargeting_tag_id = None
        self._rules = None
        self.discriminator = None

        self.is_open = is_open
        self.is_preset = is_preset
        self.reach_period = reach_period
        self.retargeting_tag_id = retargeting_tag_id
        self.rules = rules

    @property
    def is_open(self):
        """Gets the is_open of this RetargetingListServiceRuleTargetList.  # noqa: E501


        :return: The is_open of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :rtype: RetargetingListServiceIsOpen
        """
        return self._is_open

    @is_open.setter
    def is_open(self, is_open):
        """Sets the is_open of this RetargetingListServiceRuleTargetList.


        :param is_open: The is_open of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :type: RetargetingListServiceIsOpen
        """

        self._is_open = is_open

    @property
    def is_preset(self):
        """Gets the is_preset of this RetargetingListServiceRuleTargetList.  # noqa: E501


        :return: The is_preset of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :rtype: RetargetingListServiceIsPreset
        """
        return self._is_preset

    @is_preset.setter
    def is_preset(self, is_preset):
        """Sets the is_preset of this RetargetingListServiceRuleTargetList.


        :param is_preset: The is_preset of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :type: RetargetingListServiceIsPreset
        """

        self._is_preset = is_preset

    @property
    def reach_period(self):
        """Gets the reach_period of this RetargetingListServiceRuleTargetList.  # noqa: E501

        <div lang=\"ja\"> リーチの蓄積期間（1日～540日）です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。 </div> <div lang=\"en\"> Cookies validation period. (1 - 540 days) <br> This field is required in ADD operation, and is optional in SET operation. </div>   # noqa: E501

        :return: The reach_period of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :rtype: int
        """
        return self._reach_period

    @reach_period.setter
    def reach_period(self, reach_period):
        """Sets the reach_period of this RetargetingListServiceRuleTargetList.

        <div lang=\"ja\"> リーチの蓄積期間（1日～540日）です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。 </div> <div lang=\"en\"> Cookies validation period. (1 - 540 days) <br> This field is required in ADD operation, and is optional in SET operation. </div>   # noqa: E501

        :param reach_period: The reach_period of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :type: int
        """

        self._reach_period = reach_period

    @property
    def retargeting_tag_id(self):
        """Gets the retargeting_tag_id of this RetargetingListServiceRuleTargetList.  # noqa: E501

        <div lang=\"ja\"> リターゲティングタグIDです。<br> このフィールドは、ADD時に必須となります。 </div> <div lang=\"en\"> ID of Retargeting Tag. <br> This field is required in ADD operation. </div>   # noqa: E501

        :return: The retargeting_tag_id of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :rtype: str
        """
        return self._retargeting_tag_id

    @retargeting_tag_id.setter
    def retargeting_tag_id(self, retargeting_tag_id):
        """Sets the retargeting_tag_id of this RetargetingListServiceRuleTargetList.

        <div lang=\"ja\"> リターゲティングタグIDです。<br> このフィールドは、ADD時に必須となります。 </div> <div lang=\"en\"> ID of Retargeting Tag. <br> This field is required in ADD operation. </div>   # noqa: E501

        :param retargeting_tag_id: The retargeting_tag_id of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :type: str
        """

        self._retargeting_tag_id = retargeting_tag_id

    @property
    def rules(self):
        """Gets the rules of this RetargetingListServiceRuleTargetList.  # noqa: E501


        :return: The rules of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :rtype: list[RetargetingListServiceRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this RetargetingListServiceRuleTargetList.


        :param rules: The rules of this RetargetingListServiceRuleTargetList.  # noqa: E501
        :type: list[RetargetingListServiceRule]
        """

        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceRuleTargetList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceRuleTargetList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "yahoo-ads-display"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    &lt;div lang&#x3D;\&quot;ja\&quot;&gt;Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。&lt;br&gt; 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに&lt;br&gt; https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 &lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;Display Ads API Web Services supported in Yahoo! Ads API.&lt;br&gt; When you use \&quot;Try it out\&quot;, you need to register your application in advance.&lt;br&gt; As one of redirect URI for application, you need to set \&quot;https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\&quot;. &lt;/div&gt;   # noqa: E501
    """
)



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.campaign_service_operation import CampaignServiceOperation  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestCampaignServiceOperation(unittest.TestCase):
    """CampaignServiceOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CampaignServiceOperation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.campaign_service_operation.CampaignServiceOperation()  # noqa: E501
        if include_optional :
            return CampaignServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.campaign.Campaign(
                        account_id = 56,
                        ad_product_type = '0',
                        app_id = '0',
                        app_name = '0',
                        bidding_strategy = yahoo_ads_display.models.campaign_service_bidding_strategy.CampaignServiceBiddingStrategy(
                            bidding_strategy_type = 'MANUAL_CPC', ),
                        budget = yahoo_ads_display.models.campaign_service_budget.CampaignServiceBudget(
                            amount = 56,
                            budget_delivery_method = 'STANDARD', ),
                        campaign_bidding_strategy = yahoo_ads_display.models.campaign_service_campaign_bidding_strategy.CampaignServiceCampaignBiddingStrategy(
                            campaign_bidding_strategy_type = 'AUTO',
                            max_cpc_bid_value = 56,
                            max_cpv_bid_value = 56,
                            max_vcpm_bid_value = 56,
                            target_cpa_bid_value = 56, ),
                        campaign_goal = '0',
                        campaign_id = 56,
                        campaign_name = '0',
                        conversion_optimizer = yahoo_ads_display.models.campaign_service_conversion_optimizer.CampaignServiceConversionOptimizer(
                            auto_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_auto_campaign_conversion_optimizer.CampaignServiceAutoCampaignConversionOptimizer(
                                conversion_optimizer_eligibility_flg = 'ENABLE',
                                target_cpa = 56, ),
                            conversion_optimizer_type = 'MANUAL',
                            manual_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_manual_campaign_conversion_optimizer.CampaignServiceManualCampaignConversionOptimizer(
                                conversion_optimizer_training_status = 'PROCESSING', ), ),
                        device_os_type = 'ANDROID',
                        end_date = '0',
                        feed_id = 56,
                        frequency_cap = yahoo_ads_display.models.campaign_service_frequency_cap.CampaignServiceFrequencyCap(
                            frequency_level = 'CAMPAIGN',
                            frequency_time_unit = 'DAY',
                            impression = 56, ),
                        labels = [
                            yahoo_ads_display.models.campaign_service_label.CampaignServiceLabel(
                                color = '0',
                                description = '0',
                                label_id = 56,
                                label_name = '0', )
                            ],
                        serving_status = 'SERVING',
                        start_date = '0',
                        type = 'STANDARD',
                        user_status = 'ACTIVE',
                        viewable_frequency_cap = yahoo_ads_display.models.campaign_service_viewable_frequency_cap.CampaignServiceViewableFrequencyCap(
                            v_imps = 56, ), )
                    ]
            )
        else :
            return CampaignServiceOperation(
                account_id = 56,
                operand = [
                    yahoo_ads_display.models.campaign.Campaign(
                        account_id = 56,
                        ad_product_type = '0',
                        app_id = '0',
                        app_name = '0',
                        bidding_strategy = yahoo_ads_display.models.campaign_service_bidding_strategy.CampaignServiceBiddingStrategy(
                            bidding_strategy_type = 'MANUAL_CPC', ),
                        budget = yahoo_ads_display.models.campaign_service_budget.CampaignServiceBudget(
                            amount = 56,
                            budget_delivery_method = 'STANDARD', ),
                        campaign_bidding_strategy = yahoo_ads_display.models.campaign_service_campaign_bidding_strategy.CampaignServiceCampaignBiddingStrategy(
                            campaign_bidding_strategy_type = 'AUTO',
                            max_cpc_bid_value = 56,
                            max_cpv_bid_value = 56,
                            max_vcpm_bid_value = 56,
                            target_cpa_bid_value = 56, ),
                        campaign_goal = '0',
                        campaign_id = 56,
                        campaign_name = '0',
                        conversion_optimizer = yahoo_ads_display.models.campaign_service_conversion_optimizer.CampaignServiceConversionOptimizer(
                            auto_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_auto_campaign_conversion_optimizer.CampaignServiceAutoCampaignConversionOptimizer(
                                conversion_optimizer_eligibility_flg = 'ENABLE',
                                target_cpa = 56, ),
                            conversion_optimizer_type = 'MANUAL',
                            manual_campaign_conversion_optimizer = yahoo_ads_display.models.campaign_service_manual_campaign_conversion_optimizer.CampaignServiceManualCampaignConversionOptimizer(
                                conversion_optimizer_training_status = 'PROCESSING', ), ),
                        device_os_type = 'ANDROID',
                        end_date = '0',
                        feed_id = 56,
                        frequency_cap = yahoo_ads_display.models.campaign_service_frequency_cap.CampaignServiceFrequencyCap(
                            frequency_level = 'CAMPAIGN',
                            frequency_time_unit = 'DAY',
                            impression = 56, ),
                        labels = [
                            yahoo_ads_display.models.campaign_service_label.CampaignServiceLabel(
                                color = '0',
                                description = '0',
                                label_id = 56,
                                label_name = '0', )
                            ],
                        serving_status = 'SERVING',
                        start_date = '0',
                        type = 'STANDARD',
                        user_status = 'ACTIVE',
                        viewable_frequency_cap = yahoo_ads_display.models.campaign_service_viewable_frequency_cap.CampaignServiceViewableFrequencyCap(
                            v_imps = 56, ), )
                    ],
        )

    def testCampaignServiceOperation(self):
        """Test CampaignServiceOperation"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_target_service_selector import AdGroupTargetServiceSelector  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupTargetServiceSelector(unittest.TestCase):
    """AdGroupTargetServiceSelector unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupTargetServiceSelector
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_target_service_selector.AdGroupTargetServiceSelector()  # noqa: E501
        if include_optional :
            return AdGroupTargetServiceSelector(
                account_id = 56,
                ad_group_ids = [
                    56
                    ],
                campaign_ids = [
                    56
                    ],
                target_types = [
                    'AD_SCHEDULE_TARGET'
                    ],
                number_results = 1,
                start_index = 1
            )
        else :
            return AdGroupTargetServiceSelector(
                account_id = 56,
        )

    def testAdGroupTargetServiceSelector(self):
        """Test AdGroupTargetServiceSelector"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class PlacementUrlIdea(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keyword': 'str',
        'site_category': 'list[str]',
        'search_url': 'str',
        'ad_format': 'list[PlacementUrlIdeaServiceAdFormat]',
        'desktop_reaches': 'int',
        'desktop_ad_requests': 'int',
        'smart_phone_reaches': 'int',
        'smart_phone_ad_requests': 'int',
        'tablet_reaches': 'int',
        'tablet_ad_requests': 'int'
    }

    attribute_map = {
        'keyword': 'keyword',
        'site_category': 'siteCategory',
        'search_url': 'searchUrl',
        'ad_format': 'adFormat',
        'desktop_reaches': 'desktopReaches',
        'desktop_ad_requests': 'desktopAdRequests',
        'smart_phone_reaches': 'smartPhoneReaches',
        'smart_phone_ad_requests': 'smartPhoneAdRequests',
        'tablet_reaches': 'tabletReaches',
        'tablet_ad_requests': 'tabletAdRequests'
    }

    def __init__(self, keyword=None, site_category=None, search_url=None, ad_format=None, desktop_reaches=None, desktop_ad_requests=None, smart_phone_reaches=None, smart_phone_ad_requests=None, tablet_reaches=None, tablet_ad_requests=None, local_vars_configuration=None):  # noqa: E501
        """PlacementUrlIdea - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keyword = None
        self._site_category = None
        self._search_url = None
        self._ad_format = None
        self._desktop_reaches = None
        self._desktop_ad_requests = None
        self._smart_phone_reaches = None
        self._smart_phone_ad_requests = None
        self._tablet_reaches = None
        self._tablet_ad_requests = None
        self.discriminator = None

        self.keyword = keyword
        self.site_category = site_category
        self.search_url = search_url
        self.ad_format = ad_format
        self.desktop_reaches = desktop_reaches
        self.desktop_ad_requests = desktop_ad_requests
        self.smart_phone_reaches = smart_phone_reaches
        self.smart_phone_ad_requests = smart_phone_ad_requests
        self.tablet_reaches = tablet_reaches
        self.tablet_ad_requests = tablet_ad_requests

    @property
    def keyword(self):
        """Gets the keyword of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\">検索キーワードです。</div> <div lang=\"en\">Search Keyword</div>   # noqa: E501

        :return: The keyword of this PlacementUrlIdea.  # noqa: E501
        :rtype: str
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this PlacementUrlIdea.

        <div lang=\"ja\">検索キーワードです。</div> <div lang=\"en\">Search Keyword</div>   # noqa: E501

        :param keyword: The keyword of this PlacementUrlIdea.  # noqa: E501
        :type: str
        """

        self._keyword = keyword

    @property
    def site_category(self):
        """Gets the site_category of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\">検索カテゴリです。</div> <div lang=\"en\">Search Category</div>   # noqa: E501

        :return: The site_category of this PlacementUrlIdea.  # noqa: E501
        :rtype: list[str]
        """
        return self._site_category

    @site_category.setter
    def site_category(self, site_category):
        """Sets the site_category of this PlacementUrlIdea.

        <div lang=\"ja\">検索カテゴリです。</div> <div lang=\"en\">Search Category</div>   # noqa: E501

        :param site_category: The site_category of this PlacementUrlIdea.  # noqa: E501
        :type: list[str]
        """

        self._site_category = site_category

    @property
    def search_url(self):
        """Gets the search_url of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> 取得URLです。<br> 不明なURLの場合　UNKNOWN_URLが入ります。 </div> <div lang=\"en\">URL</div>   # noqa: E501

        :return: The search_url of this PlacementUrlIdea.  # noqa: E501
        :rtype: str
        """
        return self._search_url

    @search_url.setter
    def search_url(self, search_url):
        """Sets the search_url of this PlacementUrlIdea.

        <div lang=\"ja\"> 取得URLです。<br> 不明なURLの場合　UNKNOWN_URLが入ります。 </div> <div lang=\"en\">URL</div>   # noqa: E501

        :param search_url: The search_url of this PlacementUrlIdea.  # noqa: E501
        :type: str
        """

        self._search_url = search_url

    @property
    def ad_format(self):
        """Gets the ad_format of this PlacementUrlIdea.  # noqa: E501


        :return: The ad_format of this PlacementUrlIdea.  # noqa: E501
        :rtype: list[PlacementUrlIdeaServiceAdFormat]
        """
        return self._ad_format

    @ad_format.setter
    def ad_format(self, ad_format):
        """Sets the ad_format of this PlacementUrlIdea.


        :param ad_format: The ad_format of this PlacementUrlIdea.  # noqa: E501
        :type: list[PlacementUrlIdeaServiceAdFormat]
        """

        self._ad_format = ad_format

    @property
    def desktop_reaches(self):
        """Gets the desktop_reaches of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> PC でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Reach Number of PC(1000 In the case of 0)</div>   # noqa: E501

        :return: The desktop_reaches of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._desktop_reaches

    @desktop_reaches.setter
    def desktop_reaches(self, desktop_reaches):
        """Sets the desktop_reaches of this PlacementUrlIdea.

        <div lang=\"ja\"> PC でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Reach Number of PC(1000 In the case of 0)</div>   # noqa: E501

        :param desktop_reaches: The desktop_reaches of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._desktop_reaches = desktop_reaches

    @property
    def desktop_ad_requests(self):
        """Gets the desktop_ad_requests of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> PC でのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of PC(1000 In the case of 0)</div>   # noqa: E501

        :return: The desktop_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._desktop_ad_requests

    @desktop_ad_requests.setter
    def desktop_ad_requests(self, desktop_ad_requests):
        """Sets the desktop_ad_requests of this PlacementUrlIdea.

        <div lang=\"ja\"> PC でのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of PC(1000 In the case of 0)</div>   # noqa: E501

        :param desktop_ad_requests: The desktop_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._desktop_ad_requests = desktop_ad_requests

    @property
    def smart_phone_reaches(self):
        """Gets the smart_phone_reaches of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> SmartPhone でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Reach Number of SmartPhone (1000 In the case of 0)</div>   # noqa: E501

        :return: The smart_phone_reaches of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._smart_phone_reaches

    @smart_phone_reaches.setter
    def smart_phone_reaches(self, smart_phone_reaches):
        """Sets the smart_phone_reaches of this PlacementUrlIdea.

        <div lang=\"ja\"> SmartPhone でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Reach Number of SmartPhone (1000 In the case of 0)</div>   # noqa: E501

        :param smart_phone_reaches: The smart_phone_reaches of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._smart_phone_reaches = smart_phone_reaches

    @property
    def smart_phone_ad_requests(self):
        """Gets the smart_phone_ad_requests of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> SmartPhone でのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of SmartPhone(1000 In the case of 0)</div>   # noqa: E501

        :return: The smart_phone_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._smart_phone_ad_requests

    @smart_phone_ad_requests.setter
    def smart_phone_ad_requests(self, smart_phone_ad_requests):
        """Sets the smart_phone_ad_requests of this PlacementUrlIdea.

        <div lang=\"ja\"> SmartPhone でのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of SmartPhone(1000 In the case of 0)</div>   # noqa: E501

        :param smart_phone_ad_requests: The smart_phone_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._smart_phone_ad_requests = smart_phone_ad_requests

    @property
    def tablet_reaches(self):
        """Gets the tablet_reaches of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> Tablet でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Tablet(1000 In the case of 0)</div>   # noqa: E501

        :return: The tablet_reaches of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._tablet_reaches

    @tablet_reaches.setter
    def tablet_reaches(self, tablet_reaches):
        """Sets the tablet_reaches of this PlacementUrlIdea.

        <div lang=\"ja\"> Tablet でのリーチ数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">Tablet(1000 In the case of 0)</div>   # noqa: E501

        :param tablet_reaches: The tablet_reaches of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._tablet_reaches = tablet_reaches

    @property
    def tablet_ad_requests(self):
        """Gets the tablet_ad_requests of this PlacementUrlIdea.  # noqa: E501

        <div lang=\"ja\"> TabletでのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of Tablet (1000 In the case of 0)</div>   # noqa: E501

        :return: The tablet_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :rtype: int
        """
        return self._tablet_ad_requests

    @tablet_ad_requests.setter
    def tablet_ad_requests(self, tablet_ad_requests):
        """Sets the tablet_ad_requests of this PlacementUrlIdea.

        <div lang=\"ja\"> TabletでのADリクエスト数です。<br> ・1000未満の時は0が取得されます。 </div> <div lang=\"en\">AD Number of Tablet (1000 In the case of 0)</div>   # noqa: E501

        :param tablet_ad_requests: The tablet_ad_requests of this PlacementUrlIdea.  # noqa: E501
        :type: int
        """

        self._tablet_ad_requests = tablet_ad_requests

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlacementUrlIdea):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlacementUrlIdea):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AdGroupTargetServiceTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_schedule_target': 'AdGroupTargetServiceAdScheduleTarget',
        'age_target': 'AdGroupTargetServiceAgeTarget',
        'app_target': 'AdGroupTargetServiceAppTarget',
        'audience_category_target': 'AdGroupTargetServiceAudienceCategoryTarget',
        'carrier_target': 'AdGroupTargetServiceCarrierTarget',
        'device_target': 'AdGroupTargetServiceDeviceTarget',
        'gender_target': 'AdGroupTargetServiceGenderTarget',
        'geo_target': 'AdGroupTargetServiceGeoTarget',
        'interest_category_target': 'AdGroupTargetServiceInterestCategoryTarget',
        'is_remove': 'bool',
        'os_target': 'AdGroupTargetServiceOsTarget',
        'os_version_target': 'AdGroupTargetServiceOsVersionTarget',
        'placement_target': 'AdGroupTargetServicePlacementTarget',
        'search_target': 'AdGroupTargetServiceSearchTarget',
        'site_category_target': 'AdGroupTargetServiceSiteCategoryTarget',
        'site_retargeting_target': 'AdGroupTargetServiceSiteRetargetingTarget',
        'target_id': 'str',
        'target_type': 'AdGroupTargetServiceTargetType'
    }

    attribute_map = {
        'ad_schedule_target': 'adScheduleTarget',
        'age_target': 'ageTarget',
        'app_target': 'appTarget',
        'audience_category_target': 'audienceCategoryTarget',
        'carrier_target': 'carrierTarget',
        'device_target': 'deviceTarget',
        'gender_target': 'genderTarget',
        'geo_target': 'geoTarget',
        'interest_category_target': 'interestCategoryTarget',
        'is_remove': 'isRemove',
        'os_target': 'osTarget',
        'os_version_target': 'osVersionTarget',
        'placement_target': 'placementTarget',
        'search_target': 'searchTarget',
        'site_category_target': 'siteCategoryTarget',
        'site_retargeting_target': 'siteRetargetingTarget',
        'target_id': 'targetId',
        'target_type': 'targetType'
    }

    def __init__(self, ad_schedule_target=None, age_target=None, app_target=None, audience_category_target=None, carrier_target=None, device_target=None, gender_target=None, geo_target=None, interest_category_target=None, is_remove=None, os_target=None, os_version_target=None, placement_target=None, search_target=None, site_category_target=None, site_retargeting_target=None, target_id=None, target_type=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupTargetServiceTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ad_schedule_target = None
        self._age_target = None
        self._app_target = None
        self._audience_category_target = None
        self._carrier_target = None
        self._device_target = None
        self._gender_target = None
        self._geo_target = None
        self._interest_category_target = None
        self._is_remove = None
        self._os_target = None
        self._os_version_target = None
        self._placement_target = None
        self._search_target = None
        self._site_category_target = None
        self._site_retargeting_target = None
        self._target_id = None
        self._target_type = None
        self.discriminator = None

        self.ad_schedule_target = ad_schedule_target
        self.age_target = age_target
        self.app_target = app_target
        self.audience_category_target = audience_category_target
        self.carrier_target = carrier_target
        self.device_target = device_target
        self.gender_target = gender_target
        self.geo_target = geo_target
        self.interest_category_target = interest_category_target
        self.is_remove = is_remove
        self.os_target = os_target
        self.os_version_target = os_version_target
        self.placement_target = placement_target
        self.search_target = search_target
        self.site_category_target = site_category_target
        self.site_retargeting_target = site_retargeting_target
        self.target_id = target_id
        self.target_type = target_type

    @property
    def ad_schedule_target(self):
        """Gets the ad_schedule_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The ad_schedule_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceAdScheduleTarget
        """
        return self._ad_schedule_target

    @ad_schedule_target.setter
    def ad_schedule_target(self, ad_schedule_target):
        """Sets the ad_schedule_target of this AdGroupTargetServiceTarget.


        :param ad_schedule_target: The ad_schedule_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceAdScheduleTarget
        """

        self._ad_schedule_target = ad_schedule_target

    @property
    def age_target(self):
        """Gets the age_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The age_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceAgeTarget
        """
        return self._age_target

    @age_target.setter
    def age_target(self, age_target):
        """Sets the age_target of this AdGroupTargetServiceTarget.


        :param age_target: The age_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceAgeTarget
        """

        self._age_target = age_target

    @property
    def app_target(self):
        """Gets the app_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The app_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceAppTarget
        """
        return self._app_target

    @app_target.setter
    def app_target(self, app_target):
        """Sets the app_target of this AdGroupTargetServiceTarget.


        :param app_target: The app_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceAppTarget
        """

        self._app_target = app_target

    @property
    def audience_category_target(self):
        """Gets the audience_category_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The audience_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceAudienceCategoryTarget
        """
        return self._audience_category_target

    @audience_category_target.setter
    def audience_category_target(self, audience_category_target):
        """Sets the audience_category_target of this AdGroupTargetServiceTarget.


        :param audience_category_target: The audience_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceAudienceCategoryTarget
        """

        self._audience_category_target = audience_category_target

    @property
    def carrier_target(self):
        """Gets the carrier_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The carrier_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceCarrierTarget
        """
        return self._carrier_target

    @carrier_target.setter
    def carrier_target(self, carrier_target):
        """Sets the carrier_target of this AdGroupTargetServiceTarget.


        :param carrier_target: The carrier_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceCarrierTarget
        """

        self._carrier_target = carrier_target

    @property
    def device_target(self):
        """Gets the device_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The device_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceDeviceTarget
        """
        return self._device_target

    @device_target.setter
    def device_target(self, device_target):
        """Sets the device_target of this AdGroupTargetServiceTarget.


        :param device_target: The device_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceDeviceTarget
        """

        self._device_target = device_target

    @property
    def gender_target(self):
        """Gets the gender_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The gender_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceGenderTarget
        """
        return self._gender_target

    @gender_target.setter
    def gender_target(self, gender_target):
        """Sets the gender_target of this AdGroupTargetServiceTarget.


        :param gender_target: The gender_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceGenderTarget
        """

        self._gender_target = gender_target

    @property
    def geo_target(self):
        """Gets the geo_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The geo_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceGeoTarget
        """
        return self._geo_target

    @geo_target.setter
    def geo_target(self, geo_target):
        """Sets the geo_target of this AdGroupTargetServiceTarget.


        :param geo_target: The geo_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceGeoTarget
        """

        self._geo_target = geo_target

    @property
    def interest_category_target(self):
        """Gets the interest_category_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The interest_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceInterestCategoryTarget
        """
        return self._interest_category_target

    @interest_category_target.setter
    def interest_category_target(self, interest_category_target):
        """Sets the interest_category_target of this AdGroupTargetServiceTarget.


        :param interest_category_target: The interest_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceInterestCategoryTarget
        """

        self._interest_category_target = interest_category_target

    @property
    def is_remove(self):
        """Gets the is_remove of this AdGroupTargetServiceTarget.  # noqa: E501

        <div lang=\"ja\"> trueの場合、ターゲティング種別をすべて削除します。<br> このフィールドは、ADD、SETおよびREMOVE時は無視され、REPLACE時は省略可能となります。 </div> <div lang=\"en\"> If true, delete all targeting types.<br> This field will be ignored in ADD, SET and REMOVE operation, and will be optional in REPLACE operation. </div>   # noqa: E501

        :return: The is_remove of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: bool
        """
        return self._is_remove

    @is_remove.setter
    def is_remove(self, is_remove):
        """Sets the is_remove of this AdGroupTargetServiceTarget.

        <div lang=\"ja\"> trueの場合、ターゲティング種別をすべて削除します。<br> このフィールドは、ADD、SETおよびREMOVE時は無視され、REPLACE時は省略可能となります。 </div> <div lang=\"en\"> If true, delete all targeting types.<br> This field will be ignored in ADD, SET and REMOVE operation, and will be optional in REPLACE operation. </div>   # noqa: E501

        :param is_remove: The is_remove of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: bool
        """

        self._is_remove = is_remove

    @property
    def os_target(self):
        """Gets the os_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The os_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceOsTarget
        """
        return self._os_target

    @os_target.setter
    def os_target(self, os_target):
        """Sets the os_target of this AdGroupTargetServiceTarget.


        :param os_target: The os_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceOsTarget
        """

        self._os_target = os_target

    @property
    def os_version_target(self):
        """Gets the os_version_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The os_version_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceOsVersionTarget
        """
        return self._os_version_target

    @os_version_target.setter
    def os_version_target(self, os_version_target):
        """Sets the os_version_target of this AdGroupTargetServiceTarget.


        :param os_version_target: The os_version_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceOsVersionTarget
        """

        self._os_version_target = os_version_target

    @property
    def placement_target(self):
        """Gets the placement_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The placement_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServicePlacementTarget
        """
        return self._placement_target

    @placement_target.setter
    def placement_target(self, placement_target):
        """Sets the placement_target of this AdGroupTargetServiceTarget.


        :param placement_target: The placement_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServicePlacementTarget
        """

        self._placement_target = placement_target

    @property
    def search_target(self):
        """Gets the search_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The search_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceSearchTarget
        """
        return self._search_target

    @search_target.setter
    def search_target(self, search_target):
        """Sets the search_target of this AdGroupTargetServiceTarget.


        :param search_target: The search_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceSearchTarget
        """

        self._search_target = search_target

    @property
    def site_category_target(self):
        """Gets the site_category_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The site_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceSiteCategoryTarget
        """
        return self._site_category_target

    @site_category_target.setter
    def site_category_target(self, site_category_target):
        """Sets the site_category_target of this AdGroupTargetServiceTarget.


        :param site_category_target: The site_category_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceSiteCategoryTarget
        """

        self._site_category_target = site_category_target

    @property
    def site_retargeting_target(self):
        """Gets the site_retargeting_target of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The site_retargeting_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceSiteRetargetingTarget
        """
        return self._site_retargeting_target

    @site_retargeting_target.setter
    def site_retargeting_target(self, site_retargeting_target):
        """Sets the site_retargeting_target of this AdGroupTargetServiceTarget.


        :param site_retargeting_target: The site_retargeting_target of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceSiteRetargetingTarget
        """

        self._site_retargeting_target = site_retargeting_target

    @property
    def target_id(self):
        """Gets the target_id of this AdGroupTargetServiceTarget.  # noqa: E501

        <div lang=\"ja\"> ターゲットIDです。<br> このフィールドは、ADDおよびREPLACE時は省略可能となり、SETおよびREMOVE時は必須となります。<br> ※ADD時、targetTypeが以下のいずれかの場合は必須です。<br> ‐SITE_RETARGETING<br> ‐PLACEMENT_TARGET<br> ‐SEARCH_TARGET<br> ‐GEO_TARGET<br> ‐INTEREST_CATEGORY<br> ‐SITE_CATEGORY<br> ‐AUDIENCE_CATEGORY_TARGET<br> ※REPLACE時、isRemoveがtrueの場合は設定不要です。<br> <br> ‐SITE_RETARGETING: targetListId<br> ‐PLACEMENT_TARGET: placementUrlListId<br> ‐SEARCH_TARGET: searchKeywordListId<br> ‐GEO_TARGET: IM地域コード(geo)<br> ‐INTEREST_CATEGORY: カテゴリーコード(category)<br> ‐SITE_CATEGORY: カテゴリーコード(category)<br> ‐OS_VERSION_TARGET: osVersion<br> ‐AUDIENCE_CATEGORY_TARGET: オーディエンスカテゴリーコード(audience category) </div> <div lang=\"en\"> Target ID.<br> This field is optional in ADD and REPLACE operation, and is required in SET and REMOVE operation.<br> *If targetType is any of the following, this field is required in ADD operation.<br> ‐SITE_RETARGETING<br> ‐PLACEMENT_TARGET<br> ‐SEARCH_TARGET<br> ‐GEO_TARGET<br> ‐INTEREST_CATEGORY<br> ‐SITE_CATEGORY<br> ‐AUDIENCE_CATEGORY_TARGET<br> *If isRemove is true, this field does not need to be set in REPLACE operation.<br> <br> ‐SITE_RETARGETING: targetListId<br> ‐PLACEMENT_TARGET: placementUrlListId<br> ‐SEARCH_TARGET: searchKeywordListId<br> ‐GEO_TARGET: IM area code(geo)<br> ‐INTEREST_CATEGORY: category code(category)<br> ‐SITE_CATEGORY: category code(category)<br> ‐OS_VERSION_TARGET: osVersion<br> ‐AUDIENCE_CATEGORY_TARGET: audience category code(audience category) </div>   # noqa: E501

        :return: The target_id of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this AdGroupTargetServiceTarget.

        <div lang=\"ja\"> ターゲットIDです。<br> このフィールドは、ADDおよびREPLACE時は省略可能となり、SETおよびREMOVE時は必須となります。<br> ※ADD時、targetTypeが以下のいずれかの場合は必須です。<br> ‐SITE_RETARGETING<br> ‐PLACEMENT_TARGET<br> ‐SEARCH_TARGET<br> ‐GEO_TARGET<br> ‐INTEREST_CATEGORY<br> ‐SITE_CATEGORY<br> ‐AUDIENCE_CATEGORY_TARGET<br> ※REPLACE時、isRemoveがtrueの場合は設定不要です。<br> <br> ‐SITE_RETARGETING: targetListId<br> ‐PLACEMENT_TARGET: placementUrlListId<br> ‐SEARCH_TARGET: searchKeywordListId<br> ‐GEO_TARGET: IM地域コード(geo)<br> ‐INTEREST_CATEGORY: カテゴリーコード(category)<br> ‐SITE_CATEGORY: カテゴリーコード(category)<br> ‐OS_VERSION_TARGET: osVersion<br> ‐AUDIENCE_CATEGORY_TARGET: オーディエンスカテゴリーコード(audience category) </div> <div lang=\"en\"> Target ID.<br> This field is optional in ADD and REPLACE operation, and is required in SET and REMOVE operation.<br> *If targetType is any of the following, this field is required in ADD operation.<br> ‐SITE_RETARGETING<br> ‐PLACEMENT_TARGET<br> ‐SEARCH_TARGET<br> ‐GEO_TARGET<br> ‐INTEREST_CATEGORY<br> ‐SITE_CATEGORY<br> ‐AUDIENCE_CATEGORY_TARGET<br> *If isRemove is true, this field does not need to be set in REPLACE operation.<br> <br> ‐SITE_RETARGETING: targetListId<br> ‐PLACEMENT_TARGET: placementUrlListId<br> ‐SEARCH_TARGET: searchKeywordListId<br> ‐GEO_TARGET: IM area code(geo)<br> ‐INTEREST_CATEGORY: category code(category)<br> ‐SITE_CATEGORY: category code(category)<br> ‐OS_VERSION_TARGET: osVersion<br> ‐AUDIENCE_CATEGORY_TARGET: audience category code(audience category) </div>   # noqa: E501

        :param target_id: The target_id of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def target_type(self):
        """Gets the target_type of this AdGroupTargetServiceTarget.  # noqa: E501


        :return: The target_type of this AdGroupTargetServiceTarget.  # noqa: E501
        :rtype: AdGroupTargetServiceTargetType
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """Sets the target_type of this AdGroupTargetServiceTarget.


        :param target_type: The target_type of this AdGroupTargetServiceTarget.  # noqa: E501
        :type: AdGroupTargetServiceTargetType
        """

        self._target_type = target_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupTargetServiceTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupTargetServiceTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.ad_group_ad_service_page import AdGroupAdServicePage  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestAdGroupAdServicePage(unittest.TestCase):
    """AdGroupAdServicePage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdGroupAdServicePage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.ad_group_ad_service_page.AdGroupAdServicePage()  # noqa: E501
        if include_optional :
            return AdGroupAdServicePage(
                total_num_entries = 56,
                values = [
                    yahoo_ads_display.models.ad_group_ad_service_value.AdGroupAdServiceValue(
                        ad_group_ad = yahoo_ads_display.models.ad_group_ad.AdGroupAd(
                            account_id = 56,
                            ad = yahoo_ads_display.models.ad_group_ad_service_ad.AdGroupAdServiceAd(
                                ad_type = 'TEXT_LONG_AD1',
                                banner_image_ad = yahoo_ads_display.models.ad_group_ad_service_banner_image_ad.AdGroupAdServiceBannerImageAd(
                                    display_url = '0',
                                    url = '0', ),
                                banner_video_ad = yahoo_ads_display.models.ad_group_ad_service_banner_video_ad.AdGroupAdServiceBannerVideoAd(
                                    display_url = '0',
                                    is_remove_video10_sec_beacon_urls = 'TRUE',
                                    is_remove_video25_percent_beacon_urls = 'TRUE',
                                    is_remove_video3_sec_beacon_urls = 'TRUE',
                                    is_remove_video50_percent_beacon_urls = 'TRUE',
                                    is_remove_video75_percent_beacon_urls = 'TRUE',
                                    is_remove_video_complete_beacon_urls = 'TRUE',
                                    is_remove_video_start_beacon_urls = 'TRUE',
                                    thumbnail_media_id = 56,
                                    url = '0',
                                    video10_sec_beacon_urls = [
                                        '0'
                                        ],
                                    video25_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video3_sec_beacon_urls = [
                                        '0'
                                        ],
                                    video50_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video75_percent_beacon_urls = [
                                        '0'
                                        ],
                                    video_complete_beacon_urls = [
                                        '0'
                                        ],
                                    video_start_beacon_urls = [
                                        '0'
                                        ], ),
                                dynamic_ad = yahoo_ads_display.models.ad_group_ad_service_dynamic_ad.AdGroupAdServiceDynamicAd(
                                    brand_color = '0',
                                    button_text = 'FOR_MORE_INFO',
                                    campaign_banner_media_id = 56,
                                    campaign_banner_media_id2 = 56,
                                    campaign_banner_media_id3 = 56,
                                    campaign_banner_media_id4 = 56,
                                    campaign_banner_url = '0',
                                    display_url = '0',
                                    is_remove_campaign_banner_media_id = 'TRUE',
                                    is_remove_campaign_banner_media_id2 = 'TRUE',
                                    is_remove_campaign_banner_media_id3 = 'TRUE',
                                    is_remove_campaign_banner_media_id4 = 'TRUE',
                                    is_remove_campaign_banner_url = 'TRUE',
                                    logo_media_id = 56,
                                    logo_media_id2 = 56,
                                    logo_media_id3 = 56,
                                    prefix = '0',
                                    principal = '0',
                                    suffix = '0',
                                    url = '0', ),
                                mobile_ad = yahoo_ads_display.models.ad_group_ad_service_mobile_ad.AdGroupAdServiceMobileAd(
                                    description = '0',
                                    description2 = '0',
                                    display_url = '0',
                                    headline = '0',
                                    mobile_carriers = [
                                        'DOCOMO'
                                        ],
                                    url = '0', ),
                                pos_ad = yahoo_ads_display.models.ad_group_ad_service_pos_ad.AdGroupAdServicePosAd(
                                    description = '0',
                                    url = '0', ),
                                responsive_image_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_image_ad.AdGroupAdServiceResponsiveImageAd(
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    url = '0', ),
                                responsive_video_ad = yahoo_ads_display.models.ad_group_ad_service_responsive_video_ad.AdGroupAdServiceResponsiveVideoAd(
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    thumbnail_media_id = 56,
                                    url = '0', ),
                                static_frame_ad = yahoo_ads_display.models.ad_group_ad_service_static_frame_ad.AdGroupAdServiceStaticFrameAd(
                                    color_set_id = 56,
                                    description = '0',
                                    display_url = '0',
                                    headline = '0',
                                    layout = '0',
                                    logo_media_id = 56,
                                    principal = '0',
                                    size = '0',
                                    url = '0', ),
                                text_ad = yahoo_ads_display.models.ad_group_ad_service_text_ad.AdGroupAdServiceTextAd(
                                    description = '0',
                                    description2 = '0',
                                    display_url = '0',
                                    headline = '0',
                                    url = '0', ), ),
                            ad_group_id = 56,
                            ad_group_name = '0',
                            ad_id = 56,
                            ad_name = '0',
                            ad_style = 'TEXT',
                            approval_status = 'APPROVED',
                            bid = yahoo_ads_display.models.ad_group_ad_service_bid.AdGroupAdServiceBid(
                                bidding_strategy_type = 'MANUAL_CPC',
                                manual_cpc_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpc_ad_group_ad_bid.AdGroupAdServiceManualCPCAdGroupAdBid(
                                    max_cpc = 56, ),
                                manual_cpv_ad_group_ad_bid = yahoo_ads_display.models.ad_group_ad_service_manual_cpv_ad_group_ad_bid.AdGroupAdServiceManualCPVAdGroupAdBid(
                                    max_cpv = 56, ), ),
                            campaign_id = 56,
                            campaign_name = '0',
                            disapproval_reason_codes = [
                                '0'
                                ],
                            impression_beacon_urls = [
                                '0'
                                ],
                            is_remove_beacon_urls = 'TRUE',
                            is_remove_third_party_tracking_script_url = 'TRUE',
                            labels = [
                                yahoo_ads_display.models.ad_group_ad_service_label.AdGroupAdServiceLabel(
                                    color = '0',
                                    description = '0',
                                    label_id = 56,
                                    label_name = '0', )
                                ],
                            media_id = 56,
                            third_party_tracking_script_url = '0',
                            third_party_tracking_vendor = '0',
                            user_status = 'ACTIVE', ),
                        errors = [
                            yahoo_ads_display.models.error.Error(
                                code = '0',
                                message = '0',
                                details = [
                                    yahoo_ads_display.models.error_detail.ErrorDetail(
                                        request_key = '0',
                                        request_value = '0', )
                                    ], )
                            ],
                        operation_succeeded = True, )
                    ]
            )
        else :
            return AdGroupAdServicePage(
        )

    def testAdGroupAdServicePage(self):
        """Test AdGroupAdServicePage"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class CampaignMigrationServiceJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'failed_count': 'int',
        'in_progress_count': 'int',
        'job_status': 'CampaignMigrationServiceJobStatus',
        'migration_job_end_date': 'str',
        'migration_job_id': 'int',
        'migration_job_submit_date': 'str',
        'scope': 'CampaignMigrationServiceScope',
        'succeeded_count': 'int',
        'total_count': 'int'
    }

    attribute_map = {
        'account_id': 'accountId',
        'failed_count': 'failedCount',
        'in_progress_count': 'inProgressCount',
        'job_status': 'jobStatus',
        'migration_job_end_date': 'migrationJobEndDate',
        'migration_job_id': 'migrationJobId',
        'migration_job_submit_date': 'migrationJobSubmitDate',
        'scope': 'scope',
        'succeeded_count': 'succeededCount',
        'total_count': 'totalCount'
    }

    def __init__(self, account_id=None, failed_count=None, in_progress_count=None, job_status=None, migration_job_end_date=None, migration_job_id=None, migration_job_submit_date=None, scope=None, succeeded_count=None, total_count=None, local_vars_configuration=None):  # noqa: E501
        """CampaignMigrationServiceJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._failed_count = None
        self._in_progress_count = None
        self._job_status = None
        self._migration_job_end_date = None
        self._migration_job_id = None
        self._migration_job_submit_date = None
        self._scope = None
        self._succeeded_count = None
        self._total_count = None
        self.discriminator = None

        self.account_id = account_id
        self.failed_count = failed_count
        self.in_progress_count = in_progress_count
        self.job_status = job_status
        self.migration_job_end_date = migration_job_end_date
        self.migration_job_id = migration_job_id
        self.migration_job_submit_date = migration_job_submit_date
        self.scope = scope
        self.succeeded_count = succeeded_count
        self.total_count = total_count

    @property
    def account_id(self):
        """Gets the account_id of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID</div>   # noqa: E501

        :return: The account_id of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CampaignMigrationServiceJob.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID</div>   # noqa: E501

        :param account_id: The account_id of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def failed_count(self):
        """Gets the failed_count of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">失敗キャンペーン数</div> <div lang=\"en\">Number of failed campaigns</div>   # noqa: E501

        :return: The failed_count of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this CampaignMigrationServiceJob.

        <div lang=\"ja\">失敗キャンペーン数</div> <div lang=\"en\">Number of failed campaigns</div>   # noqa: E501

        :param failed_count: The failed_count of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._failed_count = failed_count

    @property
    def in_progress_count(self):
        """Gets the in_progress_count of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">進行中キャンペーン数</div> <div lang=\"en\">Number of progressing campaigns</div>   # noqa: E501

        :return: The in_progress_count of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._in_progress_count

    @in_progress_count.setter
    def in_progress_count(self, in_progress_count):
        """Sets the in_progress_count of this CampaignMigrationServiceJob.

        <div lang=\"ja\">進行中キャンペーン数</div> <div lang=\"en\">Number of progressing campaigns</div>   # noqa: E501

        :param in_progress_count: The in_progress_count of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._in_progress_count = in_progress_count

    @property
    def job_status(self):
        """Gets the job_status of this CampaignMigrationServiceJob.  # noqa: E501


        :return: The job_status of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: CampaignMigrationServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this CampaignMigrationServiceJob.


        :param job_status: The job_status of this CampaignMigrationServiceJob.  # noqa: E501
        :type: CampaignMigrationServiceJobStatus
        """

        self._job_status = job_status

    @property
    def migration_job_end_date(self):
        """Gets the migration_job_end_date of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">マイグレーションジョブ終了日時</div> <div lang=\"en\">Migration job end date</div>   # noqa: E501

        :return: The migration_job_end_date of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._migration_job_end_date

    @migration_job_end_date.setter
    def migration_job_end_date(self, migration_job_end_date):
        """Sets the migration_job_end_date of this CampaignMigrationServiceJob.

        <div lang=\"ja\">マイグレーションジョブ終了日時</div> <div lang=\"en\">Migration job end date</div>   # noqa: E501

        :param migration_job_end_date: The migration_job_end_date of this CampaignMigrationServiceJob.  # noqa: E501
        :type: str
        """

        self._migration_job_end_date = migration_job_end_date

    @property
    def migration_job_id(self):
        """Gets the migration_job_id of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">マイグレーションジョブID</div> <div lang=\"en\">Migration job ID</div>   # noqa: E501

        :return: The migration_job_id of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._migration_job_id

    @migration_job_id.setter
    def migration_job_id(self, migration_job_id):
        """Sets the migration_job_id of this CampaignMigrationServiceJob.

        <div lang=\"ja\">マイグレーションジョブID</div> <div lang=\"en\">Migration job ID</div>   # noqa: E501

        :param migration_job_id: The migration_job_id of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._migration_job_id = migration_job_id

    @property
    def migration_job_submit_date(self):
        """Gets the migration_job_submit_date of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">マイグレーションジョブ登録日時</div> <div lang=\"en\">Migration job submit date</div>   # noqa: E501

        :return: The migration_job_submit_date of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._migration_job_submit_date

    @migration_job_submit_date.setter
    def migration_job_submit_date(self, migration_job_submit_date):
        """Sets the migration_job_submit_date of this CampaignMigrationServiceJob.

        <div lang=\"ja\">マイグレーションジョブ登録日時</div> <div lang=\"en\">Migration job submit date</div>   # noqa: E501

        :param migration_job_submit_date: The migration_job_submit_date of this CampaignMigrationServiceJob.  # noqa: E501
        :type: str
        """

        self._migration_job_submit_date = migration_job_submit_date

    @property
    def scope(self):
        """Gets the scope of this CampaignMigrationServiceJob.  # noqa: E501


        :return: The scope of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: CampaignMigrationServiceScope
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this CampaignMigrationServiceJob.


        :param scope: The scope of this CampaignMigrationServiceJob.  # noqa: E501
        :type: CampaignMigrationServiceScope
        """

        self._scope = scope

    @property
    def succeeded_count(self):
        """Gets the succeeded_count of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">正常終了キャンペーン数</div> <div lang=\"en\">Number of completed campaigns</div>   # noqa: E501

        :return: The succeeded_count of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._succeeded_count

    @succeeded_count.setter
    def succeeded_count(self, succeeded_count):
        """Sets the succeeded_count of this CampaignMigrationServiceJob.

        <div lang=\"ja\">正常終了キャンペーン数</div> <div lang=\"en\">Number of completed campaigns</div>   # noqa: E501

        :param succeeded_count: The succeeded_count of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._succeeded_count = succeeded_count

    @property
    def total_count(self):
        """Gets the total_count of this CampaignMigrationServiceJob.  # noqa: E501

        <div lang=\"ja\">全キャンペーン数</div> <div lang=\"en\">Number of total campaigns</div>   # noqa: E501

        :return: The total_count of this CampaignMigrationServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this CampaignMigrationServiceJob.

        <div lang=\"ja\">全キャンペーン数</div> <div lang=\"en\">Number of total campaigns</div>   # noqa: E501

        :param total_count: The total_count of this CampaignMigrationServiceJob.  # noqa: E501
        :type: int
        """

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignMigrationServiceJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignMigrationServiceJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class ReportDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'complete_time': 'str',
        'date_range': 'ReportDefinitionServiceDateRange',
        'date_range_type': 'ReportDefinitionServiceDateRangeType',
        'download_encode': 'ReportDefinitionServiceDownloadEncode',
        'download_format': 'ReportDefinitionServiceDownloadFormat',
        'fields': 'list[str]',
        'filters': 'list[ReportDefinitionServiceFilter]',
        'frequency_range': 'ReportDefinitionServiceFrequencyRange',
        'job_status': 'ReportDefinitionServiceJobStatus',
        'lang': 'ReportDefinitionServiceLang',
        'report_job_error_detail': 'str',
        'report_job_id': 'int',
        'report_name': 'str',
        'request_time': 'str',
        'sort_fields': 'list[ReportDefinitionServiceReportSortField]',
        'zip': 'ReportDefinitionServiceZip'
    }

    attribute_map = {
        'account_id': 'accountId',
        'complete_time': 'completeTime',
        'date_range': 'dateRange',
        'date_range_type': 'dateRangeType',
        'download_encode': 'downloadEncode',
        'download_format': 'downloadFormat',
        'fields': 'fields',
        'filters': 'filters',
        'frequency_range': 'frequencyRange',
        'job_status': 'jobStatus',
        'lang': 'lang',
        'report_job_error_detail': 'reportJobErrorDetail',
        'report_job_id': 'reportJobId',
        'report_name': 'reportName',
        'request_time': 'requestTime',
        'sort_fields': 'sortFields',
        'zip': 'zip'
    }

    def __init__(self, account_id=None, complete_time=None, date_range=None, date_range_type=None, download_encode=None, download_format=None, fields=None, filters=None, frequency_range=None, job_status=None, lang=None, report_job_error_detail=None, report_job_id=None, report_name=None, request_time=None, sort_fields=None, zip=None, local_vars_configuration=None):  # noqa: E501
        """ReportDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._complete_time = None
        self._date_range = None
        self._date_range_type = None
        self._download_encode = None
        self._download_format = None
        self._fields = None
        self._filters = None
        self._frequency_range = None
        self._job_status = None
        self._lang = None
        self._report_job_error_detail = None
        self._report_job_id = None
        self._report_name = None
        self._request_time = None
        self._sort_fields = None
        self._zip = None
        self.discriminator = None

        self.account_id = account_id
        self.complete_time = complete_time
        self.date_range = date_range
        self.date_range_type = date_range_type
        self.download_encode = download_encode
        self.download_format = download_format
        self.fields = fields
        self.filters = filters
        self.frequency_range = frequency_range
        self.job_status = job_status
        self.lang = lang
        self.report_job_error_detail = report_job_error_detail
        self.report_job_id = report_job_id
        self.report_name = report_name
        self.request_time = request_time
        self.sort_fields = sort_fields
        self.zip = zip

    @property
    def account_id(self):
        """Gets the account_id of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The account_id of this ReportDefinition.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ReportDefinition.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param account_id: The account_id of this ReportDefinition.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def complete_time(self):
        """Gets the complete_time of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> ジョブ完了日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The date and time of Job completion. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The complete_time of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._complete_time

    @complete_time.setter
    def complete_time(self, complete_time):
        """Sets the complete_time of this ReportDefinition.

        <div lang=\"ja\"> ジョブ完了日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The date and time of Job completion. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param complete_time: The complete_time of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._complete_time = complete_time

    @property
    def date_range(self):
        """Gets the date_range of this ReportDefinition.  # noqa: E501


        :return: The date_range of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceDateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this ReportDefinition.


        :param date_range: The date_range of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceDateRange
        """

        self._date_range = date_range

    @property
    def date_range_type(self):
        """Gets the date_range_type of this ReportDefinition.  # noqa: E501


        :return: The date_range_type of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceDateRangeType
        """
        return self._date_range_type

    @date_range_type.setter
    def date_range_type(self, date_range_type):
        """Sets the date_range_type of this ReportDefinition.


        :param date_range_type: The date_range_type of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceDateRangeType
        """

        self._date_range_type = date_range_type

    @property
    def download_encode(self):
        """Gets the download_encode of this ReportDefinition.  # noqa: E501


        :return: The download_encode of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceDownloadEncode
        """
        return self._download_encode

    @download_encode.setter
    def download_encode(self, download_encode):
        """Sets the download_encode of this ReportDefinition.


        :param download_encode: The download_encode of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceDownloadEncode
        """

        self._download_encode = download_encode

    @property
    def download_format(self):
        """Gets the download_format of this ReportDefinition.  # noqa: E501


        :return: The download_format of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceDownloadFormat
        """
        return self._download_format

    @download_format.setter
    def download_format(self, download_format):
        """Sets the download_format of this ReportDefinition.


        :param download_format: The download_format of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceDownloadFormat
        """

        self._download_format = download_format

    @property
    def fields(self):
        """Gets the fields of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> 表示項目です。<br> このフィールドは、ADD時に必須となり、REMOVE時に無視されます。<br> 指定可能な値は、ReportDefinitionServiceのgetReportFieldsで取得されるfieldNameをご確認ください。 </div> <div lang=\"en\"> Select the fields. <br> This field is required in ADD operation, and will be ignored in REMOVE operation.<br> * Available values can be referred to fieldName field of fields object obtained by getReportFields operation of ReportDefinitionService. </div>   # noqa: E501

        :return: The fields of this ReportDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ReportDefinition.

        <div lang=\"ja\"> 表示項目です。<br> このフィールドは、ADD時に必須となり、REMOVE時に無視されます。<br> 指定可能な値は、ReportDefinitionServiceのgetReportFieldsで取得されるfieldNameをご確認ください。 </div> <div lang=\"en\"> Select the fields. <br> This field is required in ADD operation, and will be ignored in REMOVE operation.<br> * Available values can be referred to fieldName field of fields object obtained by getReportFields operation of ReportDefinitionService. </div>   # noqa: E501

        :param fields: The fields of this ReportDefinition.  # noqa: E501
        :type: list[str]
        """

        self._fields = fields

    @property
    def filters(self):
        """Gets the filters of this ReportDefinition.  # noqa: E501


        :return: The filters of this ReportDefinition.  # noqa: E501
        :rtype: list[ReportDefinitionServiceFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this ReportDefinition.


        :param filters: The filters of this ReportDefinition.  # noqa: E501
        :type: list[ReportDefinitionServiceFilter]
        """

        self._filters = filters

    @property
    def frequency_range(self):
        """Gets the frequency_range of this ReportDefinition.  # noqa: E501


        :return: The frequency_range of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceFrequencyRange
        """
        return self._frequency_range

    @frequency_range.setter
    def frequency_range(self, frequency_range):
        """Sets the frequency_range of this ReportDefinition.


        :param frequency_range: The frequency_range of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceFrequencyRange
        """

        self._frequency_range = frequency_range

    @property
    def job_status(self):
        """Gets the job_status of this ReportDefinition.  # noqa: E501


        :return: The job_status of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this ReportDefinition.


        :param job_status: The job_status of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceJobStatus
        """

        self._job_status = job_status

    @property
    def lang(self):
        """Gets the lang of this ReportDefinition.  # noqa: E501


        :return: The lang of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceLang
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this ReportDefinition.


        :param lang: The lang of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceLang
        """

        self._lang = lang

    @property
    def report_job_error_detail(self):
        """Gets the report_job_error_detail of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> ジョブエラー詳細です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Job Error Detail. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The report_job_error_detail of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._report_job_error_detail

    @report_job_error_detail.setter
    def report_job_error_detail(self, report_job_error_detail):
        """Sets the report_job_error_detail of this ReportDefinition.

        <div lang=\"ja\"> ジョブエラー詳細です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Job Error Detail. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param report_job_error_detail: The report_job_error_detail of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._report_job_error_detail = report_job_error_detail

    @property
    def report_job_id(self):
        """Gets the report_job_id of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> レポートジョブIDです。<br> このフィールドは、REMOVE時に必須となり、ADD時に無視されます。 </div> <div lang=\"en\"> Report Job Id. <br> This field is required in REMOVE operation, and will be ignored in ADD operation. </div>   # noqa: E501

        :return: The report_job_id of this ReportDefinition.  # noqa: E501
        :rtype: int
        """
        return self._report_job_id

    @report_job_id.setter
    def report_job_id(self, report_job_id):
        """Sets the report_job_id of this ReportDefinition.

        <div lang=\"ja\"> レポートジョブIDです。<br> このフィールドは、REMOVE時に必須となり、ADD時に無視されます。 </div> <div lang=\"en\"> Report Job Id. <br> This field is required in REMOVE operation, and will be ignored in ADD operation. </div>   # noqa: E501

        :param report_job_id: The report_job_id of this ReportDefinition.  # noqa: E501
        :type: int
        """

        self._report_job_id = report_job_id

    @property
    def report_name(self):
        """Gets the report_name of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> レポート名です。<br> このフィールドは、ADD時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> Report name. <br> This field is optional in ADD operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :return: The report_name of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this ReportDefinition.

        <div lang=\"ja\"> レポート名です。<br> このフィールドは、ADD時に省略可能となり、REMOVE時に無視されます。 </div> <div lang=\"en\"> Report name. <br> This field is optional in ADD operation, and will be ignored in REMOVE operation. </div>   # noqa: E501

        :param report_name: The report_name of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._report_name = report_name

    @property
    def request_time(self):
        """Gets the request_time of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\"> ジョブ依頼日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The date and time of Job request. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The request_time of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._request_time

    @request_time.setter
    def request_time(self, request_time):
        """Sets the request_time of this ReportDefinition.

        <div lang=\"ja\"> ジョブ依頼日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The date and time of Job request. <br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param request_time: The request_time of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._request_time = request_time

    @property
    def sort_fields(self):
        """Gets the sort_fields of this ReportDefinition.  # noqa: E501


        :return: The sort_fields of this ReportDefinition.  # noqa: E501
        :rtype: list[ReportDefinitionServiceReportSortField]
        """
        return self._sort_fields

    @sort_fields.setter
    def sort_fields(self, sort_fields):
        """Sets the sort_fields of this ReportDefinition.


        :param sort_fields: The sort_fields of this ReportDefinition.  # noqa: E501
        :type: list[ReportDefinitionServiceReportSortField]
        """

        self._sort_fields = sort_fields

    @property
    def zip(self):
        """Gets the zip of this ReportDefinition.  # noqa: E501


        :return: The zip of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceZip
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this ReportDefinition.


        :param zip: The zip of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceZip
        """

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReportDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class FeedDataServiceRecord(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'complete_date': 'str',
        'error_count': 'int',
        'error_rate': 'float',
        'feed_id': 'int',
        'file_upload_src': 'FeedDataServiceFileUploadSrc',
        'file_upload_status': 'FeedDataServiceFileUploadStatus',
        'is_debug': 'bool',
        'item_list_upload_id': 'int',
        'item_list_upload_type': 'FeedDataServiceItemListUploadType',
        'upload_date': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'complete_date': 'completeDate',
        'error_count': 'errorCount',
        'error_rate': 'errorRate',
        'feed_id': 'feedId',
        'file_upload_src': 'fileUploadSrc',
        'file_upload_status': 'fileUploadStatus',
        'is_debug': 'isDebug',
        'item_list_upload_id': 'itemListUploadId',
        'item_list_upload_type': 'itemListUploadType',
        'upload_date': 'uploadDate'
    }

    def __init__(self, account_id=None, complete_date=None, error_count=None, error_rate=None, feed_id=None, file_upload_src=None, file_upload_status=None, is_debug=None, item_list_upload_id=None, item_list_upload_type=None, upload_date=None, local_vars_configuration=None):  # noqa: E501
        """FeedDataServiceRecord - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._complete_date = None
        self._error_count = None
        self._error_rate = None
        self._feed_id = None
        self._file_upload_src = None
        self._file_upload_status = None
        self._is_debug = None
        self._item_list_upload_id = None
        self._item_list_upload_type = None
        self._upload_date = None
        self.discriminator = None

        self.account_id = account_id
        self.complete_date = complete_date
        self.error_count = error_count
        self.error_rate = error_rate
        self.feed_id = feed_id
        self.file_upload_src = file_upload_src
        self.file_upload_status = file_upload_status
        self.is_debug = is_debug
        self.item_list_upload_id = item_list_upload_id
        self.item_list_upload_type = item_list_upload_type
        self.upload_date = upload_date

    @property
    def account_id(self):
        """Gets the account_id of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this FeedDataServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this FeedDataServiceRecord.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this FeedDataServiceRecord.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def complete_date(self):
        """Gets the complete_date of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">取り込み完了日(yyyyMMdd)</div> <div lang=\"en\"> Complete date.<br> Format: yyyyMMdd </div>   # noqa: E501

        :return: The complete_date of this FeedDataServiceRecord.  # noqa: E501
        :rtype: str
        """
        return self._complete_date

    @complete_date.setter
    def complete_date(self, complete_date):
        """Sets the complete_date of this FeedDataServiceRecord.

        <div lang=\"ja\">取り込み完了日(yyyyMMdd)</div> <div lang=\"en\"> Complete date.<br> Format: yyyyMMdd </div>   # noqa: E501

        :param complete_date: The complete_date of this FeedDataServiceRecord.  # noqa: E501
        :type: str
        """

        self._complete_date = complete_date

    @property
    def error_count(self):
        """Gets the error_count of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">不備がある商品情報の件数</div> <div lang=\"en\">Number of item list with error.</div>   # noqa: E501

        :return: The error_count of this FeedDataServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """Sets the error_count of this FeedDataServiceRecord.

        <div lang=\"ja\">不備がある商品情報の件数</div> <div lang=\"en\">Number of item list with error.</div>   # noqa: E501

        :param error_count: The error_count of this FeedDataServiceRecord.  # noqa: E501
        :type: int
        """

        self._error_count = error_count

    @property
    def error_rate(self):
        """Gets the error_rate of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">エラー率</div> <div lang=\"en\">Error rate.</div>   # noqa: E501

        :return: The error_rate of this FeedDataServiceRecord.  # noqa: E501
        :rtype: float
        """
        return self._error_rate

    @error_rate.setter
    def error_rate(self, error_rate):
        """Sets the error_rate of this FeedDataServiceRecord.

        <div lang=\"ja\">エラー率</div> <div lang=\"en\">Error rate.</div>   # noqa: E501

        :param error_rate: The error_rate of this FeedDataServiceRecord.  # noqa: E501
        :type: float
        """

        self._error_rate = error_rate

    @property
    def feed_id(self):
        """Gets the feed_id of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">Feedを識別するId</div> <div lang=\"en\">Feed ID.</div>   # noqa: E501

        :return: The feed_id of this FeedDataServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._feed_id

    @feed_id.setter
    def feed_id(self, feed_id):
        """Sets the feed_id of this FeedDataServiceRecord.

        <div lang=\"ja\">Feedを識別するId</div> <div lang=\"en\">Feed ID.</div>   # noqa: E501

        :param feed_id: The feed_id of this FeedDataServiceRecord.  # noqa: E501
        :type: int
        """

        self._feed_id = feed_id

    @property
    def file_upload_src(self):
        """Gets the file_upload_src of this FeedDataServiceRecord.  # noqa: E501


        :return: The file_upload_src of this FeedDataServiceRecord.  # noqa: E501
        :rtype: FeedDataServiceFileUploadSrc
        """
        return self._file_upload_src

    @file_upload_src.setter
    def file_upload_src(self, file_upload_src):
        """Sets the file_upload_src of this FeedDataServiceRecord.


        :param file_upload_src: The file_upload_src of this FeedDataServiceRecord.  # noqa: E501
        :type: FeedDataServiceFileUploadSrc
        """

        self._file_upload_src = file_upload_src

    @property
    def file_upload_status(self):
        """Gets the file_upload_status of this FeedDataServiceRecord.  # noqa: E501


        :return: The file_upload_status of this FeedDataServiceRecord.  # noqa: E501
        :rtype: FeedDataServiceFileUploadStatus
        """
        return self._file_upload_status

    @file_upload_status.setter
    def file_upload_status(self, file_upload_status):
        """Sets the file_upload_status of this FeedDataServiceRecord.


        :param file_upload_status: The file_upload_status of this FeedDataServiceRecord.  # noqa: E501
        :type: FeedDataServiceFileUploadStatus
        """

        self._file_upload_status = file_upload_status

    @property
    def is_debug(self):
        """Gets the is_debug of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">trueはデバッグモードでの実行を意味します。</div> <div lang=\"en\">&#34;true&#34; means to run in debug mode.</div>   # noqa: E501

        :return: The is_debug of this FeedDataServiceRecord.  # noqa: E501
        :rtype: bool
        """
        return self._is_debug

    @is_debug.setter
    def is_debug(self, is_debug):
        """Sets the is_debug of this FeedDataServiceRecord.

        <div lang=\"ja\">trueはデバッグモードでの実行を意味します。</div> <div lang=\"en\">&#34;true&#34; means to run in debug mode.</div>   # noqa: E501

        :param is_debug: The is_debug of this FeedDataServiceRecord.  # noqa: E501
        :type: bool
        """

        self._is_debug = is_debug

    @property
    def item_list_upload_id(self):
        """Gets the item_list_upload_id of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">アップロードした商品情報を識別するID</div> <div lang=\"en\">Uploaded item list ID.</div>   # noqa: E501

        :return: The item_list_upload_id of this FeedDataServiceRecord.  # noqa: E501
        :rtype: int
        """
        return self._item_list_upload_id

    @item_list_upload_id.setter
    def item_list_upload_id(self, item_list_upload_id):
        """Sets the item_list_upload_id of this FeedDataServiceRecord.

        <div lang=\"ja\">アップロードした商品情報を識別するID</div> <div lang=\"en\">Uploaded item list ID.</div>   # noqa: E501

        :param item_list_upload_id: The item_list_upload_id of this FeedDataServiceRecord.  # noqa: E501
        :type: int
        """

        self._item_list_upload_id = item_list_upload_id

    @property
    def item_list_upload_type(self):
        """Gets the item_list_upload_type of this FeedDataServiceRecord.  # noqa: E501


        :return: The item_list_upload_type of this FeedDataServiceRecord.  # noqa: E501
        :rtype: FeedDataServiceItemListUploadType
        """
        return self._item_list_upload_type

    @item_list_upload_type.setter
    def item_list_upload_type(self, item_list_upload_type):
        """Sets the item_list_upload_type of this FeedDataServiceRecord.


        :param item_list_upload_type: The item_list_upload_type of this FeedDataServiceRecord.  # noqa: E501
        :type: FeedDataServiceItemListUploadType
        """

        self._item_list_upload_type = item_list_upload_type

    @property
    def upload_date(self):
        """Gets the upload_date of this FeedDataServiceRecord.  # noqa: E501

        <div lang=\"ja\">アップロード日(yyyyMMdd)</div> <div lang=\"en\"> Upload date.<br> Format: yyyyMMdd </div>   # noqa: E501

        :return: The upload_date of this FeedDataServiceRecord.  # noqa: E501
        :rtype: str
        """
        return self._upload_date

    @upload_date.setter
    def upload_date(self, upload_date):
        """Sets the upload_date of this FeedDataServiceRecord.

        <div lang=\"ja\">アップロード日(yyyyMMdd)</div> <div lang=\"en\"> Upload date.<br> Format: yyyyMMdd </div>   # noqa: E501

        :param upload_date: The upload_date of this FeedDataServiceRecord.  # noqa: E501
        :type: str
        """

        self._upload_date = upload_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedDataServiceRecord):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedDataServiceRecord):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_ads_display.configuration import Configuration


class AuditLogServiceJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'audit_log_job_end_date': 'str',
        'audit_log_job_id': 'int',
        'audit_log_job_name': 'str',
        'audit_log_job_start_date': 'str',
        'audit_log_job_user_name': 'str',
        'campaign_ids': 'list[int]',
        'date_range': 'AuditLogServiceDateRange',
        'job_status': 'AuditLogServiceJobStatus',
        'lang': 'AuditLogServiceLang',
        'progress': 'int',
        'update_source': 'AuditLogServiceUpdateSource'
    }

    attribute_map = {
        'account_id': 'accountId',
        'audit_log_job_end_date': 'auditLogJobEndDate',
        'audit_log_job_id': 'auditLogJobId',
        'audit_log_job_name': 'auditLogJobName',
        'audit_log_job_start_date': 'auditLogJobStartDate',
        'audit_log_job_user_name': 'auditLogJobUserName',
        'campaign_ids': 'campaignIds',
        'date_range': 'dateRange',
        'job_status': 'jobStatus',
        'lang': 'lang',
        'progress': 'progress',
        'update_source': 'updateSource'
    }

    def __init__(self, account_id=None, audit_log_job_end_date=None, audit_log_job_id=None, audit_log_job_name=None, audit_log_job_start_date=None, audit_log_job_user_name=None, campaign_ids=None, date_range=None, job_status=None, lang=None, progress=None, update_source=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogServiceJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._audit_log_job_end_date = None
        self._audit_log_job_id = None
        self._audit_log_job_name = None
        self._audit_log_job_start_date = None
        self._audit_log_job_user_name = None
        self._campaign_ids = None
        self._date_range = None
        self._job_status = None
        self._lang = None
        self._progress = None
        self._update_source = None
        self.discriminator = None

        self.account_id = account_id
        self.audit_log_job_end_date = audit_log_job_end_date
        self.audit_log_job_id = audit_log_job_id
        self.audit_log_job_name = audit_log_job_name
        self.audit_log_job_start_date = audit_log_job_start_date
        self.audit_log_job_user_name = audit_log_job_user_name
        self.campaign_ids = campaign_ids
        self.date_range = date_range
        self.job_status = job_status
        self.lang = lang
        self.progress = progress
        self.update_source = update_source

    @property
    def account_id(self):
        """Gets the account_id of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The account_id of this AuditLogServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AuditLogServiceJob.

        <div lang=\"ja\"> アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Account ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param account_id: The account_id of this AuditLogServiceJob.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def audit_log_job_end_date(self):
        """Gets the audit_log_job_end_date of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの終了日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The job end date (YYYY-MM-DDTHH:MI:SS+9:00).<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The audit_log_job_end_date of this AuditLogServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._audit_log_job_end_date

    @audit_log_job_end_date.setter
    def audit_log_job_end_date(self, audit_log_job_end_date):
        """Sets the audit_log_job_end_date of this AuditLogServiceJob.

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの終了日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The job end date (YYYY-MM-DDTHH:MI:SS+9:00).<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param audit_log_job_end_date: The audit_log_job_end_date of this AuditLogServiceJob.  # noqa: E501
        :type: str
        """

        self._audit_log_job_end_date = audit_log_job_end_date

    @property
    def audit_log_job_id(self):
        """Gets the audit_log_job_id of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 操作履歴のダウンロードジョブIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The operation history job ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The audit_log_job_id of this AuditLogServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._audit_log_job_id

    @audit_log_job_id.setter
    def audit_log_job_id(self, audit_log_job_id):
        """Sets the audit_log_job_id of this AuditLogServiceJob.

        <div lang=\"ja\"> 操作履歴のダウンロードジョブIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The operation history job ID.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param audit_log_job_id: The audit_log_job_id of this AuditLogServiceJob.  # noqa: E501
        :type: int
        """

        self._audit_log_job_id = audit_log_job_id

    @property
    def audit_log_job_name(self):
        """Gets the audit_log_job_name of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 操作履歴のダウンロードジョブ名です。<br> このフィールドは、リクエストの場合は省略可能となります。 </div> <div lang=\"en\"> The operation history job name.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The audit_log_job_name of this AuditLogServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._audit_log_job_name

    @audit_log_job_name.setter
    def audit_log_job_name(self, audit_log_job_name):
        """Sets the audit_log_job_name of this AuditLogServiceJob.

        <div lang=\"ja\"> 操作履歴のダウンロードジョブ名です。<br> このフィールドは、リクエストの場合は省略可能となります。 </div> <div lang=\"en\"> The operation history job name.<br> This field is optional in requests. </div>   # noqa: E501

        :param audit_log_job_name: The audit_log_job_name of this AuditLogServiceJob.  # noqa: E501
        :type: str
        """

        self._audit_log_job_name = audit_log_job_name

    @property
    def audit_log_job_start_date(self):
        """Gets the audit_log_job_start_date of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの開始日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The job start date (YYYY-MM-DDTHH:MI:SS+9:00).<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The audit_log_job_start_date of this AuditLogServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._audit_log_job_start_date

    @audit_log_job_start_date.setter
    def audit_log_job_start_date(self, audit_log_job_start_date):
        """Sets the audit_log_job_start_date of this AuditLogServiceJob.

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの開始日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The job start date (YYYY-MM-DDTHH:MI:SS+9:00).<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param audit_log_job_start_date: The audit_log_job_start_date of this AuditLogServiceJob.  # noqa: E501
        :type: str
        """

        self._audit_log_job_start_date = audit_log_job_start_date

    @property
    def audit_log_job_user_name(self):
        """Gets the audit_log_job_user_name of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの実行ユーザー名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The user name who executes the operation history job.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The audit_log_job_user_name of this AuditLogServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._audit_log_job_user_name

    @audit_log_job_user_name.setter
    def audit_log_job_user_name(self, audit_log_job_user_name):
        """Sets the audit_log_job_user_name of this AuditLogServiceJob.

        <div lang=\"ja\"> 操作履歴ダウンロードジョブの実行ユーザー名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> The user name who executes the operation history job.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param audit_log_job_user_name: The audit_log_job_user_name of this AuditLogServiceJob.  # noqa: E501
        :type: str
        """

        self._audit_log_job_user_name = audit_log_job_user_name

    @property
    def campaign_ids(self):
        """Gets the campaign_ids of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> ダウンロード対象のキャンペーンIDです。<br> このフィールドは、リクエストの場合は省略可能となります。 </div> <div lang=\"en\"> Campaign ID of the download object.<br> This field is optional in requests. </div>   # noqa: E501

        :return: The campaign_ids of this AuditLogServiceJob.  # noqa: E501
        :rtype: list[int]
        """
        return self._campaign_ids

    @campaign_ids.setter
    def campaign_ids(self, campaign_ids):
        """Sets the campaign_ids of this AuditLogServiceJob.

        <div lang=\"ja\"> ダウンロード対象のキャンペーンIDです。<br> このフィールドは、リクエストの場合は省略可能となります。 </div> <div lang=\"en\"> Campaign ID of the download object.<br> This field is optional in requests. </div>   # noqa: E501

        :param campaign_ids: The campaign_ids of this AuditLogServiceJob.  # noqa: E501
        :type: list[int]
        """

        self._campaign_ids = campaign_ids

    @property
    def date_range(self):
        """Gets the date_range of this AuditLogServiceJob.  # noqa: E501


        :return: The date_range of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceDateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this AuditLogServiceJob.


        :param date_range: The date_range of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceDateRange
        """

        self._date_range = date_range

    @property
    def job_status(self):
        """Gets the job_status of this AuditLogServiceJob.  # noqa: E501


        :return: The job_status of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this AuditLogServiceJob.


        :param job_status: The job_status of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceJobStatus
        """

        self._job_status = job_status

    @property
    def lang(self):
        """Gets the lang of this AuditLogServiceJob.  # noqa: E501


        :return: The lang of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceLang
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this AuditLogServiceJob.


        :param lang: The lang of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceLang
        """

        self._lang = lang

    @property
    def progress(self):
        """Gets the progress of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\"> 処理進捗です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Displays progress in integers from 1 to 100.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The progress of this AuditLogServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this AuditLogServiceJob.

        <div lang=\"ja\"> 処理進捗です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\"> Displays progress in integers from 1 to 100.<br> Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param progress: The progress of this AuditLogServiceJob.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def update_source(self):
        """Gets the update_source of this AuditLogServiceJob.  # noqa: E501


        :return: The update_source of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceUpdateSource
        """
        return self._update_source

    @update_source.setter
    def update_source(self, update_source):
        """Sets the update_source of this AuditLogServiceJob.


        :param update_source: The update_source of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceUpdateSource
        """

        self._update_source = update_source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogServiceJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogServiceJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 ディスプレイ広告 API リファレンス / Yahoo! Ads Display Ads API Reference

    <div lang=\"ja\">Yahoo!広告 ディスプレイ広告 APIのWebサービスについて説明します。<br> 「Try it out」のご利用には、事前にアプリケーションの登録が必要です。また、アプリケーションのリダイレクトURIの1つに<br> https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.htmlを登録してください。 </div> <div lang=\"en\">Display Ads API Web Services supported in Yahoo! Ads API.<br> When you use \"Try it out\", you need to register your application in advance.<br> As one of redirect URI for application, you need to set \"https://yahoojp-marketing.github.io/ads-display-api-documents/oauth2-redirect.html\". </div>   # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import yahoo_ads_display
from yahoo_ads_display.models.stats_service_value import StatsServiceValue  # noqa: E501
from yahoo_ads_display.rest import ApiException

class TestStatsServiceValue(unittest.TestCase):
    """StatsServiceValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test StatsServiceValue
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = yahoo_ads_display.models.stats_service_value.StatsServiceValue()  # noqa: E501
        if include_optional :
            return StatsServiceValue(
                account_id = 56,
                ad_group_stats_value = yahoo_ads_display.models.stats_service_ad_group_stats_value.StatsServiceAdGroupStatsValue(
                    campaign_id = 56,
                    campaign_name = '0',
                    ad_group_id = 56,
                    ad_group_name = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ), ),
                ad_stats_value = yahoo_ads_display.models.stats_service_ad_stats_value.StatsServiceAdStatsValue(
                    campaign_id = 56,
                    campaign_name = '0',
                    ad_group_id = 56,
                    ad_group_name = '0',
                    ad_id = 56,
                    ad_name = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ), ),
                campaign_stats_value = yahoo_ads_display.models.stats_service_campaign_stats_value.StatsServiceCampaignStatsValue(
                    campaign_id = 56,
                    campaign_name = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ), ),
                errors = [
                    yahoo_ads_display.models.error.Error(
                        code = '0',
                        message = '0',
                        details = [
                            yahoo_ads_display.models.error_detail.ErrorDetail(
                                request_key = '0',
                                request_value = '0', )
                            ], )
                    ],
                image_stats_value = yahoo_ads_display.models.stats_service_image_stats_value.StatsServiceImageStatsValue(
                    media_id = 56,
                    media_name = '0',
                    media_title = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ), ),
                operation_succeeded = True,
                period_custom_date = yahoo_ads_display.models.stats_service_period_custom_date.StatsServicePeriodCustomDate(
                    stats_end_date = '0',
                    stats_start_date = '0', ),
                stats_period = 'REALTIME_TODAY',
                target_stats_value = yahoo_ads_display.models.stats_service_target_stats_value.StatsServiceTargetStatsValue(
                    campaign_id = 56,
                    campaign_name = '0',
                    ad_group_id = 56,
                    ad_group_name = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ),
                    target = yahoo_ads_display.models.stats_service_target.StatsServiceTarget(
                        ad_schedule_target = yahoo_ads_display.models.stats_service_ad_schedule_target.StatsServiceAdScheduleTarget(
                            day_of_week = 'MONDAY',
                            end_hour = 56,
                            start_hour = 56, ),
                        age_target = yahoo_ads_display.models.stats_service_age_target.StatsServiceAgeTarget(
                            age = 'GT_RANGE13_14',
                            estimate_flg = 'PAUSED', ),
                        app_target = yahoo_ads_display.models.stats_service_app_target.StatsServiceAppTarget(
                            device_app_type = 'APP', ),
                        audience_category_target = yahoo_ads_display.models.stats_service_audience_category_target.StatsServiceAudienceCategoryTarget(
                            audience_category_type = '0',
                            category_name_en = '0',
                            category_name_ja = '0', ),
                        carrier_target = yahoo_ads_display.models.stats_service_carrier_target.StatsServiceCarrierTarget(
                            carrier_type = 'DOCOMO', ),
                        device_target = yahoo_ads_display.models.stats_service_device_target.StatsServiceDeviceTarget(
                            device_type = 'DESKTOP', ),
                        gender_target = yahoo_ads_display.models.stats_service_gender_target.StatsServiceGenderTarget(
                            gender = 'ST_MALE', ),
                        geo_target = yahoo_ads_display.models.stats_service_geo_target.StatsServiceGeoTarget(
                            geo_name_en = '0',
                            geo_name_ja = '0', ),
                        interest_category_target = yahoo_ads_display.models.stats_service_interest_category_target.StatsServiceInterestCategoryTarget(
                            category_full_name_en = '0',
                            category_full_name_ja = '0', ),
                        os_target = yahoo_ads_display.models.stats_service_os_target.StatsServiceOsTarget(
                            device_os_type = 'IOS', ),
                        os_version_target = yahoo_ads_display.models.stats_service_os_version_target.StatsServiceOsVersionTarget(
                            os_version = '0', ),
                        placement_target = yahoo_ads_display.models.stats_service_placement_target.StatsServicePlacementTarget(
                            placement_url_list_name = '0',
                            placement_url_list_type = 'WHITE_LIST', ),
                        search_target = yahoo_ads_display.models.stats_service_search_target.StatsServiceSearchTarget(
                            search_keyword_list_name = '0', ),
                        site_category_target = yahoo_ads_display.models.stats_service_site_category_target.StatsServiceSiteCategoryTarget(
                            category_full_name_en = '0',
                            category_full_name_ja = '0', ),
                        site_retargeting_target = yahoo_ads_display.models.stats_service_site_retargeting_target.StatsServiceSiteRetargetingTarget(
                            target_list_deliver_type = 'INCLUDE',
                            target_list_name = '0', ),
                        target_id = '0',
                        target_setting = 'NONE',
                        target_type = 'AD_SCHEDULE_TARGET', ), ),
                type = 'CAMPAIGN',
                video_stats_value = yahoo_ads_display.models.stats_service_video_stats_value.StatsServiceVideoStatsValue(
                    media_id = 56,
                    video_name = '0',
                    video_title = '0',
                    stats = yahoo_ads_display.models.stats.Stats(
                        imps = 56,
                        imps_prev = 1.337,
                        click_cnt = 56,
                        click_rate = 1.337,
                        click_rate_prev = 1.337,
                        cost = 1.337,
                        avg_cpc = 1.337,
                        conversions = 56,
                        conversion_rate = 1.337,
                        conversions_via_ad_click = 56,
                        conversion_rate_via_ad_click = 1.337,
                        all_conversions = 56,
                        all_conversion_rate = 1.337,
                        cpa = '0',
                        conversion_value = '0',
                        value_per_conversions = '0',
                        conv_value_per_cost = 1.337,
                        all_conv_value_per_cost = 1.337,
                        conv_value_via_ad_click_per_cost = 1.337,
                        all_conversion_value = '0',
                        value_per_all_conversions = '0',
                        conversion_value_via_ad_click = '0',
                        value_per_conversions_via_ad_click = '0',
                        cpa_via_ad_click = '0',
                        all_cpa = '0',
                        cross_device_conversions = 56,
                        avg_deliver_rank = 1.337,
                        measured_imps = 1.337,
                        total_vimps = 56,
                        measured_imps_rate = 1.337,
                        vimps = 56,
                        viewable_imps_rate = 1.337,
                        in_view_rate = 1.337,
                        viewable_clicks = 1.337,
                        in_view_click_cnt = 56,
                        viewable_click_rate = 1.337,
                        in_view_click_rate = 1.337,
                        paid_video_views = 56,
                        paid_video_view_rate = 1.337,
                        average_cpv = 1.337,
                        video_views = 56,
                        video_views_to25 = 56,
                        video_views_to50 = 56,
                        video_views_to75 = 56,
                        video_views_to95 = 56,
                        video_views_to100 = 56,
                        video_views_to3_sec = 56,
                        video_views_to10_sec = 56,
                        average_rate_video_viewed = 1.337,
                        average_duration_video_viewed = 1.337,
                        impression_share = 1.337,
                        budget_impression_share_lost_rate = 1.337,
                        rank_impression_share_lost_rate = 1.337, ), )
            )
        else :
            return StatsServiceValue(
        )

    def testStatsServiceValue(self):
        """Test StatsServiceValue"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
